#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/webalizer-update.sh - paramater update script
#
# Creation   :  2009-05-24 jv
# Last update:  $Id: webalizer-update.sh 66644 2019-07-15 14:58:55Z hbfl $
#
# Copyright (c) 2009 the eisfair team, team(at)eisfair(dot)org
# Copyright (c) 2014-2023 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> /tmp/webalizer-update-trace$$.log
#set -x
# set package name
package_name=webalizer

# include configlib for using printvar
. /var/install/include/configlib

# include apache2 config
. /etc/config.d/apache2

VERSION=3.2.1

# ---------------------------------------------------------------------------
# Set the default values for configuration
# ---------------------------------------------------------------------------
get_defaults()
{
    START_WEBALIZER='no'

    WEBALIZER_CRON='55 23 * * *'
    WEBALIZER_LANG_TYPE='english'
    WEBALIZER_ACCESS_AUTH_SEND_MAIL_FROM=''
    WEBALIZER_QUIET='no'
    WEBALIZER_REALLY_QUIET='no'
    WEBALIZER_TIME_ME='no'

    WEBALIZER_VHOSTS_RUN_ALL="no"
    WEBALIZER_VHOSTS_ALIAS='httpd'
    WEBALIZER_VHOSTS_TITLE='Auswertung von'
    WEBALIZER_VHOSTS_BGCOLOR='#E8E8E8'
    WEABLIZER_VHOSTS_COLOR_SCHEME='default'

    WEBALIZER_VHOSTS_ACCESS_ALL='no'
    WEBALIZER_VHOSTS_ACCESS_AUTH='no'
    WEBALIZER_VHOSTS_ACCESS_HOST=''
    WEBALIZER_VHOSTS_ACCESS_IP=''
    WEBALIZER_VHOSTS_ACCESS_LOCAL='yes'

    WEBALIZER_HOST_N='1'
    WEBALIZER_HOST_1_NAME=''
    WEBALIZER_HOST_1_ACTIVE='no'
    WEBALIZER_HOST_1_ALIAS='httpd'
    WEBALIZER_HOST_1_ACCESS_LOG="$APACHE2_ACCESS_LOG"
    WEBALIZER_HOST_1_HOST_NAME="$APACHE2_SERVER_NAME"
    WEBALIZER_HOST_1_TITLE='Auswertung von'
    WEBALIZER_HOST_1_BGCOLOR='#E8E8E8'      
    WEABLIZER_HOST_1_COLOR_SCHEME='default'
    WEBALIZER_HOST_1_TYPE='clf'

    WEBALIZER_HOST_1_ACCESS_ALL='no'
    WEBALIZER_HOST_1_ACCESS_AUTH='no'
    WEBALIZER_HOST_1_ACCESS_HOST=''
    WEBALIZER_HOST_1_ACCESS_IP=''
    WEBALIZER_HOST_1_ACCESS_LOCAL='yes'
}

# ---------------------------------------------------------------------------
# rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi

    # read old values from apache2_webalizer
    if [ -f /etc/config.d/apache2_webalizer ]
    then
        . /etc/config.d/apache2_webalizer
        rm -f /etc/config.d/apache2_webalizer
        old_conf=true
    fi
}

# ----------------------------------------------------------------------------
# write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf "${package_name}" '2014-03-23' 'hbfl' 
    # -----------------------------------------------------------------------
    echo "# Webalizer-VERSION ${VERSION}"
    # -----------------------------------------------------------------------
    printgroup 'Basic configuration'
    # -----------------------------------------------------------------------

    if ${old_conf:-false}
    then
        START_WEBALIZER="${START_APACHE2_WEBALIZER}"
        WEBALIZER_CRON="${APACHE2_WEBALIZER_CRON}"
        WEBALIZER_LANG_TYPE="${APACHE2_WEBALIZER_LANG_TYPE}"
        WEBALIZER_ACCESS_AUTH_SEND_MAIL_FROM="${APACHE2_WEBALIZER_ACCESS_AUTH_SEND_MAIL}"
        WEBALIZER_QUIET="${APACHE2_WEBALIZER_QUIET}"
        WEBALIZER_REALLY_QUIET="${APACHE2_WEBALIZER_REALLY_QUIET}"
        WEBALIZER_TIME_ME="${APACHE2_WEBALIZER_TIME_ME}"
    fi

    printvar 'START_WEBALIZER'
    printcomment        'Start webalizer'


    printvar 'WEBALIZER_CRON'
    printcomment        'Everyday at 23:xx'

    printvar 'WEBALIZER_LANG_TYPE'
    printcomment        'english, german or french'

    printvar 'WEBALIZER_ACCESS_AUTH_SEND_MAIL_FROM'
    printcomment        'Use: empty, no mail or Mailadress from Admin,'
    printcomment        'required for outgoing mail'

    printvar 'WEBALIZER_QUIET'
    printcomment        'The Quiet option suppresses output messages'

    printvar 'WEBALIZER_REALLY_QUIET'
    printcomment        'ReallyQuiet will supress all messages including'
    printcomment        'errors and warnings.'

    printvar 'WEBALIZER_TIME_ME'
    printcomment        'TimeMe allows you to force the display of timing'
    printcomment        'information at the end of processing.'

    # ------------------------------------------------------------------------
    printgroup 'Apache VHOST configuration'
    # ------------------------------------------------------------------------

    if ${old_conf:-false}
    then
        WEBALIZER_VHOSTS_RUN_ALL="${APACHE2_WEBALIZER_VHOSTS_RUN_ALL}"
        WEBALIZER_VHOSTS_ALIAS="${APACHE2_WEBALIZER_VHOSTS_ALIAS}"
        WEBALIZER_VHOSTS_TITLE="${APACHE2_WEBALIZER_VHOSTS_TITLE}"
        WEBALIZER_VHOSTS_BGCOLOR="${APACHE2_WEBALIZER_VHOSTS_BGCOLOR}"
        WEABLIZER_VHOSTS_COLOR_SCHEME="${APACHE2_WEABLIZER_VHOSTS_COLOR_SCHEME}"
    fi

    printvar 'WEBALIZER_VHOSTS_RUN_ALL'
    printcomment        'Use: yes or no for run Webalizer '
    printcomment        'over all apache2 VHosts'

    printvar 'WEBALIZER_VHOSTS_ALIAS'
    printcomment        'Alias - the name to get the analysis '
    printcomment        'in the browser'

    printvar 'WEBALIZER_VHOSTS_TITLE'
    printcomment        'The title at the top of the analysis'

    printvar 'WEBALIZER_VHOSTS_BGCOLOR'
    printcomment        'The backgroundcolor'

    printvar 'WEABLIZER_VHOSTS_COLOR_SCHEME'
    printcomment        'Use: default, aqua or fresh'


    if ${old_conf:-false}
    then
        if [ "${APACHE2_WEBALIZER_VHOSTS_ACCESS_ALL}" = "yes" ]
        then
            vhosts_ac_con=yes
        fi 

        WEBALIZER_VHOSTS_ACCESS_ALL="${APACHE2_WEBALIZER_VHOSTS_ACCESS_ALL}"

        if [ "${APACHE2_WEBALIZER_VHOSTS_ACCESS_AUTH}" = "yes" ]
        then
            vhosts_ac_con=yes
        fi

        WEBALIZER_VHOSTS_ACCESS_AUTH="${APACHE2_WEBALIZER_VHOSTS_ACCESS_AUTH}"

        if [ "${APACHE2_WEBALIZER_VHOSTS_ACCESS_HOST}" = "yes" ]
        then
            vhosts_ac_con=yes
            WEBALIZER_VHOSTS_ACCESS_HOST="${APACHE2_WEBALIZER_VHOSTS_HOST}"
        fi

        if [ "${APACHE2_WEBALIZER_VHOSTS_ACCESS_IP}" = "yes" ]
        then
            vhosts_ac_con=yes
            WEBALIZER_VHOSTS_ACCESS_IP="${APACHE2_WEBALIZER_VHOSTS_IP}"
        fi

        if [ "${APACHE2_WEBALIZER_VHOSTS_ACCESS_LOCAL}" = "yes" ]
        then
            vhosts_ac_con=yes
        fi

        WEBALIZER_VHOSTS_ACCESS_LOCAL="${APACHE2_WEBALIZER_VHOSTS_ACCESS_LOCAL}"

        if [ "${vhosts_ac_con}" = "yes" ]
        then    
            WEBALIZER_VHOSTS_ACCESS_CONTROL='yes'
        fi
    fi


    if [ "${WEBALIZER_VHOSTS_ACCESS_CONTROL}" = "no" ]
    then  
        WEBALIZER_VHOSTS_ACCESS_ALL='yes'
    fi

    printvar 'WEBALIZER_VHOSTS_ACCESS_ALL'
    printcomment        'Use: yes or no, access for all over the world'

    printvar 'WEBALIZER_VHOSTS_ACCESS_AUTH'
    printcomment        'Use: yes or no, access with user and password'

    printvar 'WEBALIZER_VHOSTS_ACCESS_HOST'
    printcomment        'Use: hostname or domain,'
    printcomment        'multiple with space as separator'

    printvar 'WEBALIZER_VHOSTS_ACCESS_IP'
    printcomment        'Use: ip for your host or network,'
    printcomment        'multiple with space as separator'

    printvar 'WEBALIZER_VHOSTS_ACCESS_LOCAL'
    printcomment        'Use: yes or no, only local access'

    # ------------------------------------------------------------------------
    printgroup 'Optional logfiles'
    # ------------------------------------------------------------------------

    if ${old_conf:-false}
    then
        WEBALIZER_HOST_N="${APACHE2_WEBALIZER_HOST_N}"
    fi

    printvar 'WEBALIZER_HOST_N'
    printcomment        'Count of hosts'

    idx=1
    while [ ${idx} -le ${WEBALIZER_HOST_N:-0} ]
    do
        if ${old_conf:-false}
        then
            eval WEBALIZER_HOST_${idx}_NAME='${APACHE2_WEBALIZER_HOST_'${idx}'_NAME}'
            eval WEBALIZER_HOST_${idx}_ACTIVE='${APACHE2_WEBALIZER_HOST_'${idx}'_ACTIVE}'
            eval WEBALIZER_HOST_${idx}_ALIAS='${APACHE2_WEBALIZER_HOST_'${idx}'_ALIAS}'
            eval WEBALIZER_HOST_${idx}_ACCESS_LOG='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_LOG}'
            eval WEBALIZER_HOST_${idx}_HOST_NAME='${APACHE2_WEBALIZER_HOST_'${idx}'_HOST_NAME}'
            eval WEBALIZER_HOST_${idx}_TITLE='${APACHE2_WEBALIZER_HOST_'${idx}'_TITLE}'
            eval WEBALIZER_HOST_${idx}_BGCOLOR='${APACHE2_WEBALIZER_HOST_'${idx}'_BGCOLOR}'
            eval WEABLIZER_HOST_${idx}_COLOR_SCHEME='${APACHE2_WEABLIZER_HOST_'${idx}'_COLOR_SCHEME}'
            eval WEBALIZER_HOST_${idx}_TYPE='${APACHE2_WEBALIZER_HOST_'${idx}'_TYPE}'
        fi

        printvar 'WEBALIZER_HOST_'${idx}'_NAME'
        printcomment    'Use a name, its only for you'

        printvar 'WEBALIZER_HOST_'${idx}'_ACTIVE'
        printcomment    'Use: yes or no'

        printvar 'WEBALIZER_HOST_'${idx}'_ALIAS'
        printcomment    'Where to put the analysis'

        printvar 'WEBALIZER_HOST_'${idx}'_ACCESS_LOG'
        printcomment    'Accesslog of Apache'

        printvar 'WEBALIZER_HOST_'${idx}'_HOST_NAME'
        printcomment    'Hostname of the (V)Host'

        printvar 'WEBALIZER_HOST_'${idx}'_TITLE'
        printcomment    'The title at the top of the analysis'

        printvar 'WEBALIZER_HOST_'${idx}'_BGCOLOR'
        printcomment    'The backgroundcolor'

        printvar 'WEABLIZER_HOST_'${idx}'_COLOR_SCHEME'
        printcomment    'Use: default, aqua or fresh'

        printvar 'WEBALIZER_HOST_'${idx}'_TYPE'
        printcomment    "'clf' for Apache, 'squid' for Squid,"
        printcomment    "'ftp' for FTP"


        if ${old_conf:-false}
        then
            eval host_ac_all='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_ALL}'
            
            if [ "${host_ac_all}" = "yes" ]
            then
                host_ac_con='yes'
            fi
            eval WEBALIZER_HOST_${idx}_ACCESS_ALL='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_ALL}'
            
            eval host_ac_auth='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_AUTH}'

            if [ "${host_ac_auth}" = "yes" ]
            then
                host_ac_con='yes'
            fi            
    
            eval WEBALIZER_HOST_${idx}_ACCESS_AUTH='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_AUTH}'
      
            eval host_ac_host='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_HOST}'
           
            if [ "${host_ac_host}" = "yes" ]
            then
                host_ac_con='yes'         
                eval WEBALIZER_HOST_${idx}_ACCESS_HOST='${APACHE2_WEBALIZER_HOST_'${idx}'_HOST}'
            fi 

            eval host_ac_ip='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_IP}'

            if [ "${host_ac_ip}" = "yes" ]
            then
                host_ac_con='yes'
                eval WEBALIZER_HOST_${idx}_ACCESS_IP='${APACHE2_WEBALIZER_HOST_'${idx}'_IP}'
            fi

            eval host_ac_local='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_LOCAL}'

            if [ "${host_ac_local}" = "yes" ]
            then
                host_ac_con='yes'
            fi

            eval WEBALIZER_HOST_${idx}_LOCAL='${APACHE2_WEBALIZER_HOST_'${idx}'_ACCESS_LOCAL}'
            
            if [ "${host_ac_con}" = "yes" ]
            then
                eval WEBALIZER_HOST_${idx}_ACCESS_CONTROL='yes'
            else
                eval WEBALIZER_HOST_${idx}_ACCESS_CONTROL='no'
            fi
        fi

        eval ac_con_n='${WEBALIZER_HOST_'${idx}'_ACCESS_CONTROL}'

        if [ "${ac_con_n}" = "no" ]
        then 
            eval WEBALIZER_HOST_${idx}_ACCESS_ALL='yes'
        fi
                 
        printvar 'WEBALIZER_HOST_'${idx}'_ACCESS_ALL'
        printcomment    'Use: yes or no, access for all over the world'

        printvar 'WEBALIZER_HOST_'${idx}'_ACCESS_AUTH'
        printcomment    'Use: yes or no, access with user and password'

        printvar 'WEBALIZER_HOST_'${idx}'_ACCESS_HOST'
        printcomment    'Use: hostname or domain,'
        printcomment    'multiple with space as separator'

        printvar 'WEBALIZER_HOST_'${idx}'_ACCESS_IP'
        printcomment    'Use: ip for your host or network,'
        printcomment    'multiple with space as separator'

        printvar 'WEBALIZER_HOST_'${idx}'_ACCESS_LOCAL'
        printcomment    'Use: yes or no, only local access'

        idx=$((${idx} + 1))
    done

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2014-03-23' 'hbfl' >/etc/check.d/${package_name}
cat >> /etc/check.d/${package_name} <<EOF
# Variable                            OPT_VARIABLE                      VARIABLE_N        VALUE
START_WEBALIZER                       -                                 -                 YESNO

WEBALIZER_CRON                        START_WEBALIZER                   -                 CRONTAB
WEBALIZER_LANG_TYPE                   START_WEBALIZER                   -                 WEBALIZER_LANG_TYPE_CUI
WEBALIZER_ACCESS_AUTH_SEND_MAIL_FROM  START_WEBALIZER                   -                 EMAILADDR
WEBALIZER_QUIET                       START_WEBALIZER                   -                 YESNO
WEBALIZER_REALLY_QUIET                START_WEBALIZER                   -                 YESNO
WEBALIZER_TIME_ME                     START_WEBALIZER                   -                 YESNO 

WEBALIZER_VHOSTS_RUN_ALL              START_WEBALIZER                   -                 YESNO
WEBALIZER_VHOSTS_ALIAS                WEBALIZER_VHOSTS_RUN_ALL          -                 NONE
WEBALIZER_VHOSTS_TITLE                WEBALIZER_VHOSTS_RUN_ALL          -                 NONE
WEBALIZER_VHOSTS_BGCOLOR              WEBALIZER_VHOSTS_RUN_ALL          -                 NONE
WEABLIZER_VHOSTS_COLOR_SCHEME         WEBALIZER_VHOSTS_RUN_ALL          -                 WEBALIZER_COLOR_SCHEME_CUI

WEBALIZER_VHOSTS_ACCESS_ALL           WEBALIZER_VHOSTS_RUN_ALL          -                 YESNO
WEBALIZER_VHOSTS_ACCESS_AUTH          !WEBALIZER_VHOSTS_ACCESS_ALL      -                 YESNO
WEBALIZER_VHOSTS_ACCESS_HOST          !WEBALIZER_VHOSTS_ACCESS_ALL      -                 NONE
WEBALIZER_VHOSTS_ACCESS_IP            !WEBALIZER_VHOSTS_ACCESS_ALL      -                 NONE
WEBALIZER_VHOSTS_ACCESS_LOCAL         !WEBALIZER_VHOSTS_ACCESS_ALL      -                 YESNO


WEBALIZER_HOST_N                      START_WEBALIZER                   -                 NUMERIC
WEBALIZER_HOST_%_NAME                 START_WEBALIZER                   WEBALIZER_HOST_N  NONE
WEBALIZER_HOST_%_ACTIVE               START_WEBALIZER                   WEBALIZER_HOST_N  YESNO
WEBALIZER_HOST_%_ALIAS                WEBALIZER_HOST_%_ACTIVE           WEBALIZER_HOST_N  NONE
WEBALIZER_HOST_%_ACCESS_LOG           WEBALIZER_HOST_%_ACTIVE           WEBALIZER_HOST_N  ABS_PATH
WEBALIZER_HOST_%_HOST_NAME            WEBALIZER_HOST_%_ACTIVE           WEBALIZER_HOST_N  NONE
WEBALIZER_HOST_%_TITLE                WEBALIZER_HOST_%_ACTIVE           WEBALIZER_HOST_N  NONE
WEBALIZER_HOST_%_BGCOLOR              WEBALIZER_HOST_%_ACTIVE           WEBALIZER_HOST_N  NONE
WEABLIZER_HOST_%_COLOR_SCHEME         WEBALIZER_HOST_%_ACTIVE           WEBALIZER_HOST_N  WEBALIZER_COLOR_SCHEME_CUI
WEBALIZER_HOST_%_TYPE                 WEBALIZER_HOST_%_ACTIVE           WEBALIZER_HOST_N  WEBALIZER_HOST_TYPE_CUI

WEBALIZER_HOST_%_ACCESS_ALL           WEBALIZER_HOST_%_ACTIVE           WEBALIZER_HOST_N  YESNO
WEBALIZER_HOST_%_ACCESS_AUTH          !WEBALIZER_HOST_%_ACCESS_ALL      WEBALIZER_HOST_N  YESNO
WEBALIZER_HOST_%_ACCESS_HOST          !WEBALIZER_HOST_%_ACCESS_ALL      WEBALIZER_HOST_N  NONE
WEBALIZER_HOST_%_ACCESS_IP            !WEBALIZER_HOST_%_ACCESS_ALL      WEBALIZER_HOST_N  NONE
WEBALIZER_HOST_%_ACCESS_LOCAL         !WEBALIZER_HOST_%_ACCESS_ALL      WEBALIZER_HOST_N  YESNO
EOF

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${package_name}
    chown root /etc/check.d/${package_name}


printgpl --check_exp ${package_name} '2014-03-23' 'hbfl' >/etc/check.d/${package_name}.exp
cat >> /etc/check.d/${package_name}.exp <<EOF
WEBALIZER_HOST_TYPE_CUI    = 'clf|squid|ftp|w3c'
                           : 'Use only: clf for Apache squid, ftp or w3c'
WEBALIZER_LANG_TYPE_CUI    = 'english|german|french'
                           : 'Use only english, german or french'
WEBALIZER_COLOR_SCHEME_CUI = 'default|aqua|fresh'
                           : 'Use only default, aqua or fresh'
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.exp
    chown root /etc/check.d/${package_name}.exp


printgpl --check_ext ${package_name} '2014-03-23' 'hbfl' >/etc/check.d/${package_name}.ext
cat >>/etc/check.d/${package_name}.ext <<EOF
if (webalizer_access_auth_send_mail_from)
then
    set mail = "no"
    stat("/usr/sbin/sendmail", res)
    if (res_res == "OK")
    then
        set mail
    fi

    if (!mail)
    then
        error "No mail package found, please install any mail package before you activate WEBALIZER_ACCESS_AUTH_SEND_MAIL_FROM !"
    fi
fi
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.ext
    chown root /etc/check.d/${package_name}.ext
}
# ----------------------------------------------------------------------------
# main
# ----------------------------------------------------------------------------
main()
{
    get_defaults
    
    # write default config file
    make_config_file /etc/default.d/${package_name}

    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}
   
# ---------------------------------------------------------------------------
# call function main
# ---------------------------------------------------------------------------
main "${@}"

# ----------------------------------------------------------------------------
# end
# ----------------------------------------------------------------------------
